-----------------------------------------------------------------------------------------------
-- Client Lua Script for FinalFive
-----------------------------------------------------------------------------------------------
require "Window"
--------------------------------------------------------------------------
-- FinalFive Module Definition
-----------------------------------------------------------------------------------------------
local FinalFive = {} 
local GeminiLocale, L
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
local hasOne = false
local hasTwo = false
local hasThree = false
local hasFour = false
local hasFive = false
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function FinalFive:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 
	o.bFinalFiveIsOn = true
	o.nFinalFiveOptions = {
		{
				psipoint = 1,
				soundlabel = Apollo.GetString("Options_AddonOff"),
				soundId = -1
		},
		{
				psipoint = 2,
				soundlabel = Apollo.GetString("Options_AddonOff"),
				soundId = -1
		},
		{
				psipoint = 3,
				soundlabel = Apollo.GetString("Options_AddonOff"),
				soundId = -1
		},
		{
				psipoint = 4,
				soundlabel = Apollo.GetString("Options_AddonOff"),
				soundId = -1
		},
		{
				psipoint = 5,
				soundlabel = "Sound 1",
				soundId = 128
		}
	}
    return o
end
function FinalFive:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {"Gemini:Locale-1.0"}
	--If not esper do not load
	local unitPlayer = GameLib.GetPlayerUnit()
	if unitPlayer then
		if unitPlayer:GetClassId() ~= GameLib.CodeEnumClass.Esper then
			return 	
		end	
	end	
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
-----------------------------------------------------------------------------------------------
-- FinalFive OnLoad
-----------------------------------------------------------------------------------------------
function FinalFive:OnLoad()
	self.xmlDoc = XmlDoc.CreateFromFile("FinalFive.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
	GeminiLocale = Apollo.GetPackage("Gemini:Locale-1.0").tPackage
    L = GeminiLocale:GetLocale("FinalFive", false)
	Apollo.LoadSprites("FinalFive_img.xml")
end
-----------------------------------------------------------------------------------------------
-- FinalFive OnDocLoaded
-----------------------------------------------------------------------------------------------
function FinalFive:OnDocLoaded()
	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "FinalFiveForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
	    self.wndMain:Show(false, true)
		self.wndMain:FindChild("GeneralBtn"):SetCheck(true)
		if self.bFinalFiveIsOn then
			self.wndMain:FindChild("MuteSwitch"):SetCheck(false)
		else
			self.wndMain:FindChild("MuteSwitch"):SetCheck(true)
		end
		self.xmlDoc = nil
		
		--
		Apollo.RegisterSlashCommand("ffoff", "OnFinalFiveOff", self)
		Apollo.RegisterSlashCommand("ffon", "OnFinalFiveOn", self)
		Apollo.RegisterSlashCommand("ffhelp", "OnFinalFiveHelp", self)
		Apollo.RegisterSlashCommand("ffconfig", "OnFinalFiveConfig", self)
		Apollo.RegisterEventHandler("InterfaceMenuListHasLoaded", "OnInterfaceMenuListHasLoaded", self)
		Apollo.RegisterEventHandler("ShowFFMenu", "OnShowFFMenu", self)
		Apollo.RegisterEventHandler("OptionsUpdated_FFPreferences","InitializeControls", self)
		Apollo.RegisterEventHandler("VarChange_FrameCount", "OnPSIPointsGained", self)
		--
		self.mapDDParents = {
			--hud options
			{
				wnd = self.wndMain:FindChild("DropTogglePSIOneSound"),
				nConsoleVar = "general.PSIOne",
				strRadioGroup = "GeneralPSIOneGroup"
			},
			{
				wnd = self.wndMain:FindChild("DropTogglePSITwoSound"),
				nConsoleVar = "general.PSITwo",
				strRadioGroup = "GeneralPSITwoGroup"
			},
			{
				wnd = self.wndMain:FindChild("DropTogglePSIThreeSound"),
				nConsoleVar = "general.PSIThree",
				strRadioGroup = "GeneralPSIThreeGroup"
			},
			{
				wnd = self.wndMain:FindChild("DropTogglePSIFourSound"),
				nConsoleVar = "general.PSIFour",
				strRadioGroup = "GeneralPSIFourGroup"
			},
			{
				wnd = self.wndMain:FindChild("DropTogglePSIFiveSound"),
				nConsoleVar = "general.PSIFive",
				strRadioGroup = "GeneralPSIFiveGroup"
			}
		}
		for idx, wndDD in pairs(self.mapDDParents) do
			wndDD.wnd:AttachWindow(wndDD.wnd:FindChild("ChoiceContainer"))
			wndDD.wnd:FindChild("ChoiceContainer"):Show(false)
		end		
		-- Trads
		GeminiLocale:TranslateWindow(L, self.wndMain)
		self.wndMain:FindChild("Notice"):SetText(L["helpnotice"])
		self.wndMain:FindChild("HelpPanel"):SetText(L["helptext"])
		self:InitializeControls()
	end
end
-----------------------------------------------------------------------------------------------
-- FinalFive OnSave
-----------------------------------------------------------------------------------------------
function FinalFive:OnSave(eType)
	if eType ~= GameLib.CodeEnumAddonSaveLevel.Character then
		return
	end
	local tSave =
	{
		bFinalFiveIsOn  = self.bFinalFiveIsOn,
		nFinalFiveOptions = self.nFinalFiveOptions,
	}
	return tSave
end
-----------------------------------------------------------------------------------------------
-- FinalFive OnRestore
-----------------------------------------------------------------------------------------------
function FinalFive:OnRestore(eType, tSavedData)
	if eType ~= GameLib.CodeEnumAddonSaveLevel.Character then
		return
	end
	
	if tSavedData then
		if tSavedData.bFinalFiveIsOn then
			self.bFinalFiveIsOn  = true
		else
			self.bFinalFiveIsOn  = false
		end	
		
		if tSavedData.nFinalFiveOptions then
			self.nFinalFiveOptions= tSavedData.nFinalFiveOptions
		end
	end
end
-----------------------------------------------------------------------------------------------
-- FinalFive Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here
function FinalFive:InitializeControls()
	for idx, option in pairs(self.nFinalFiveOptions) do
		if option.soundlabel then
			self.mapDDParents[idx].wnd:SetText(option.soundlabel); 
		end	
	end
end

function FinalFive:OnInterfaceMenuListHasLoaded()
	Event_FireGenericEvent("InterfaceMenuList_NewAddOn", "FinalFive", {"ShowFFMenu", "", "CRB_Esper:sprEsper_CombatCount5"})
end
---------------------------------------------------------------------------------------------------
-- FinalFiveForm Functions
---------------------------------------------------------------------------------------------------
function FinalFive:OnShowFFMenu()
	self.wndMain:FindChild("HelpPanel"):SetText(L["helptext"])
	self.wndMain:Invoke()
end
function FinalFive:OnCloseWindow()
	self.wndMain:Close()
end
function FinalFive:OnGeneralOptionsCheck(wndHandler, wndControl)
	self.wndMain:FindChild("Content:General"):Show(true)
	self.wndMain:FindChild("Content:Help"):Show(false)
end
function FinalFive:OnHelpOptionsCheck( wndHandler, wndControl, eMouseButton )
	self.wndMain:FindChild("Content:General"):Show(false)
	self.wndMain:FindChild("Content:Help"):Show(true)
	self.wndMain:FindChild("HelpPanel"):SetText(L["helptext"])
end
function FinalFive:OnHUDRadio( wndHandler, wndControl, eMouseButton )
	for idx, wndDD in pairs(self.mapDDParents) do
		if wndDD.wnd == wndControl:GetParent():GetParent():GetParent() then
			-- INIT SOUNDS ID HERE
			self.nFinalFiveOptions[idx].soundlabel=wndControl:GetText(); 
			if wndControl:GetName() == "-1" then
				self.nFinalFiveOptions[idx].soundId = -1;
			elseif wndControl:GetName() == "0" then
				Sound.PlayFile(idx..".wav")
				self.nFinalFiveOptions[idx].soundId = 0
			elseif wndControl:GetName() then
				Sound.Play(wndControl:GetName())
				self.nFinalFiveOptions[idx].soundId = tonumber(wndControl:GetName())
			end
			wndControl:GetParent():GetParent():SetText(wndControl:GetText())
			break
		end
	end

	Event_FireGenericEvent("OptionsUpdated_FFPreferences")
	wndControl:GetParent():GetParent():Show(false)
end
function FinalFive:OnMute()
	if self.bFinalFiveIsOn then
			self.bFinalFiveIsOn = false
			ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_System, "FinalFive is now off")
	else
			self.bFinalFiveIsOn = true
			ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_System, "FinalFive is now on")	
	end
end
function FinalFive:OnFinalFiveOff()
	self.bFinalFiveIsOn = false
	self.wndMain:FindChild("MuteSwitch"):SetCheck(true)
	ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_System, "FinalFive is now off")
end
function FinalFive:OnFinalFiveOn()
	self.bFinalFiveIsOn = true
	self.wndMain:FindChild("MuteSwitch"):SetCheck(false)
	ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_System, "FinalFive is now on")
end
function FinalFive:OnFinalFiveHelp()
	ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_System, "FinalFive commands :")
	ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_System, "- /ffon enable sound alert")
	ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_System, "- /ffoff disable sound alert")
	ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_System, "- /ffconfig sound configuration")
end
function FinalFive:OnFinalFiveConfig()
	self.wndMain:FindChild("Content:General"):Show(true)
	self.wndMain:FindChild("Content:Help"):Show(false)
	self.wndMain:Invoke()
end
-----------------------------------------------------------------------------------------------
-- FinalFive CORE Function
-----------------------------------------------------------------------------------------------
function FinalFive:OnPSIPointsGained()
	local unitPlayer = GameLib.GetPlayerUnit()
    if self.bFinalFiveIsOn and unitPlayer then
		local nbPSIPoints = unitPlayer:GetResource(1)
		if nbPSIPoints == 1 and not hasOne then
			if self.nFinalFiveOptions[nbPSIPoints].soundId > 0 then
				Sound.Play(self.nFinalFiveOptions[nbPSIPoints].soundId)
			elseif self.nFinalFiveOptions[nbPSIPoints].soundId == 0 then
				Sound.PlayFile(nbPSIPoints..".wav");
			end
			hasOne = true
		elseif nbPSIPoints == 2 and not hasTwo then
			if self.nFinalFiveOptions[nbPSIPoints].soundId > 0 then
				Sound.Play(self.nFinalFiveOptions[nbPSIPoints].soundId)
			elseif self.nFinalFiveOptions[nbPSIPoints].soundId == 0 then
				Sound.PlayFile(nbPSIPoints..".wav");
			end
			hasTwo = true
		elseif nbPSIPoints == 3 and not hasThree then
			if self.nFinalFiveOptions[nbPSIPoints].soundId > 0 then
				Sound.Play(self.nFinalFiveOptions[nbPSIPoints].soundId)
			elseif self.nFinalFiveOptions[nbPSIPoints].soundId == 0 then
				Sound.PlayFile(nbPSIPoints..".wav");
			end
			hasThree = true
		elseif nbPSIPoints == 4 and not hasFour then
			if self.nFinalFiveOptions[nbPSIPoints].soundId > 0 then
				Sound.Play(self.nFinalFiveOptions[nbPSIPoints].soundId)
			elseif self.nFinalFiveOptions[nbPSIPoints].soundId == 0 then
				Sound.PlayFile(nbPSIPoints..".wav");
			end
			hasFour = true
		elseif nbPSIPoints == 5 and not hasFive then
			if self.nFinalFiveOptions[nbPSIPoints].soundId>0 then
				Sound.Play(self.nFinalFiveOptions[nbPSIPoints].soundId)
			elseif self.nFinalFiveOptions[nbPSIPoints].soundId == 0 then
				Sound.PlayFile(nbPSIPoints..".wav");
			end
			hasFive = true
		end
		if nbPSIPoints ~= 1 and hasOne then
			hasOne = false;
		end
		if nbPSIPoints ~= 2 and hasTwo then
			hasTwo = false;
		end
		if nbPSIPoints ~= 3 and hasThree then
			hasThree = false;
		end
		if nbPSIPoints ~= 4 and hasFour then
			hasFour = false;
		end
		if nbPSIPoints ~= 5 and hasFive then
			hasFive = false;
		end
	end
end
-----------------------------------------------------------------------------------------------
-- FinalFive Instance
-----------------------------------------------------------------------------------------------
local FinalFiveInst = FinalFive:new()
FinalFiveInst:Init()